@@ -17,16 +17,20 @@ def rolling_replacer() -> None:
 @rolling_replacer.command(name="blue-green")
 @click.argument("autoscaling_group_blue_name")
 @click.argument("target_group_blue_name")
+@click.argument("listener_rule_blue_arn")
 @click.argument("autoscaling_group_green_name")
 @click.argument("target_group_green_name")
+@click.argument("listener_rule_green_arn")
 @click.argument("load_balancer_name")
 @click.option("-v", "--verbose", count=True)
 @configure_logging
 def blue_green(
     autoscaling_group_blue_name: str,
     target_group_blue_name: str,
+    listener_rule_blue_arn: str,
     autoscaling_group_green_name: str,
     target_group_green_name: str,
+    listener_rule_green_arn: str,
     load_balancer_name: str,
     verbose: int,
 ) -> None:
@@ -35,8 +39,10 @@ def blue_green(
             load_balancer_name,
             autoscaling_group_blue_name,
             target_group_blue_name,
+            listener_rule_blue_arn,
             autoscaling_group_green_name,
             target_group_green_name,
+            listener_rule_green_arn,
         ),
     )
 
