@@ -8,6 +8,11 @@ client = boto3.client("elbv2")
 
 class ReRouteTrafficStep(BlueGreenStep):
     def execute(self) -> bool:
-        aws_load_balancer.set_target_group(self.load_balancer, self.inactive_target_group.arn)
+        aws_load_balancer.set_rules_priority(
+            self.listener_rule_blue.arn,
+            self.listener_rule_green.priority,
+            self.listener_rule_green.arn,
+            self.listener_rule_blue.priority,
+        )
 
         return True
